pub struct Tracked<Inner> { /* private fields */ }Expand description
An object wrapper that tracks allocations and attributes them to a specific group.
Provides methods and implementations to help ensure that operations against/using the wrapped object have all allocations properly tracked and attributed to a given group.
Implements Future when the wrapped object itself implements Future.
Implementations
Sourceimpl<Inner> Tracked<Inner>
impl<Inner> Tracked<Inner>
Sourcepub fn into_parts(self) -> (ResourceGroupToken, Inner)
pub fn into_parts(self) -> (ResourceGroupToken, Inner)
Consumes this object and returns the inner object and tracking token.